---
title: "Introduction"
type: Chapter
slug: true
front: false
---

>> The real long-term future of computing consists of figuring out how to make the best possible use we can out of the literal millions of devices which already exist.

<cite>(Solderpunk, 2020, Cited in de Valk, 2022)
<span style="display: none;">[@devalkSalvagedComputing]</span></cite>

Beware! If you’ve picked up this publication expecting to learn how to make a flawless, DAW-less, in tune and always working polysynth, think again. However, if you, like me, are interested in making screamy, dreamy, sound devices using an alternative resource: trash, you’ve come to the right place.

When I first read about salvage computing, I got very excited. Being part of the DIY Sound community, as a sound practitioner and hardware hacker, I’ve developed a growing discomfort with some aspects of the practice. Over the past few years, I’ve hosted workshops around circuit bending[^circuit-bending] and LOFI sound devices in and around Rotterdam. These workshops are meant as an accessible way to get people tinkering with electronics, through something infinitely playful: making instruments[^playful].

[^circuit-bending]: the practice around hacking discarded toys to find sonic potential through creating shorts, or sometimes literally bending the circuit.

[^playful]: Making instruments is an engaging way to learn about and work with the flow of electricity

In an ecosystem where a printer is only printing with a costly subscription [^printer-subscription], disruptive products become obsolete within a year[^AI-pin], fixing your own flat tires is outsourced [^swapfiets] and some smartphones literally have to be frozen to be able to replace the battery [^frozen], it’s clear we’re no longer in charge of our own devices. Warranty-void stickers and lengthy terms and conditions scare us into compliance.

I’ve noticed how empowering these first-time soldering workshops can be in taking back this autonomy by making (or breaking) a circuit together. They are a shared attempt to uncover some of the black boxes in our own products [@hertzZombieMediaCircuit2012]. However, the toys and materials used in the workshops are single-use [^single-use] and, with ease, thrown out afterward. The carelessness notion creeps in that waste has no value, and is easily replaceable, and broke my heart a bit, one workshop at a time.

[^printer-subscription]: HP’s “all-inclusive” printers can only be used with an active subscription [@hachmanNightmareRealHP2024].

[^AI-pin]: Humane Inc. Ai Pin closed their servers within one year after releasing their *A.I. Pin*. Now, you can only ask this piece of hardware how many batteries it has left. [@chokkattuWhatYourDefunct2025]

[^swapfiets]: Swapfiets promote their bike subscriptions as “We give you a bike that you never have to repair”

[^frozen]: The Nothing Phone scored a 1/10 in iFixit's repairability score [@havardEssentialPhoneTeardown2017]

[^single-use]: and often require much preparation in terms of collecting, transporting, repairing, testing, and cleaning.

This is where the field guide comes into play: Can we shift the practice of playful tinkering to acknowledge, rather than ignore, the waste streams they are part of? Limiting ourselves to only use salvaged components and discovering; is it possible to live off (create with) electronic components salvaged in the wild? And what would such a practice entail?

Because salvage is not just about reusing materials; but about confronting the systems that create the waste in the first place. Not only the obsolete media but also the by-product of the entire production lifecycle of an electronic product; From the mining of minerals that make up the hardware to the inevitable disposal site [@gabrysSalvage2012]. Since the rate at which waste is collected and recycled isn't growing at the same pace as our collective buying and production, the landfills will continue to grow. Parikka even goes as far to say as that recycling is ultimately "trade-waste", where our abandoned devices are shipped across the ocean <ins>hier moet nog wat achter</ins>[@parikkaDustMatter2012].

## Beyond the kit
The preference for buying new is noticeable in the DIY synth community as well. When publishing a project, it's common to share a pre-filled webshop cart along with the schematics or even sell it as a pre-compiled kit[^KIT]. To me, this goes against the ethos of DIY that resonates with me the most: making do with what you have, with a focus on doing, and not the outcome [@hertzArtDIYElectronics2023]. Instead, a whole new market is created consisting of Lego-like kits. These kits gloss over the actual challenges and difficulties of creating sound devices, preventing the development of much-needed problem-solving skills, and not actually discovering anything new [@CooperativeExperimentalismSharing].

[^KIT]: ![Kit from Bastl Instruments](/chapters/bastl_kit.webp)

Instead, what you will learn to build using this guide is a starting point. Small electronic circuits that produce sound on their own, but can also be duplicated, manipulated, and modulated into something completely different. The chaos is up to you. Some experience with electronics is preferred, as the guide will not go into detail about voltages and amps, or how to solder. There are other, more suitable resources for that. On that note, I am by no means an expert in electronics. This guide represents my personal understanding of electronics, which, in no doubt, contains incorrect assumptions or oversimplifications. It can however offer you insights and practical tools to incorporate salvaging into your own practice.

Within the DIY Sound community, DIWO workshops are a common way of sharing knowledge [@richardsDIYMakerCommunities2017], covering a wide range of topics, from the construction to bending and hacking and live coding. Where it is not only about sound <ins>afmaken</ins>

In the DIY synth community, DIWO (Do It With Others) is a common way of sharing knowledge. These often very horizontal workshops are a way of skillsharing [^horizontal-workshops]. The field guide is no exception on that, and partly came together during (un)repair cafe events at klank.school. I think these DIWO practices are very powerfull. Not only saves it you from having to make an investment in specific tools, working with electronics and waste can be a frustrating process, and DIWO can help share the leed. Having conversations about the material whilest working with the material cna be a way to deepen the relationship with the mateiral.<ins>afmaken</ins>

[^horizontal-workshops]: <ins>uitleggen</ins>

Repair is often and historically organised as a social activity - opening up workplaces and sharing knowledge[@matternStepStepThinking2024]. <ins>expand more on the social</ins>. This notion is a major part of the DIY Synth community [@richardsDIYElectronicMusic2013]. By being part of workshops and gatherings around DIY sound and repair I've noticed how empowering these exchanges can be [^exchange]. This guide itself is created during and around so-called *(un)repair nights[^unrepair-night]* at the klankschool[^about-klankschool]. . The frustrating process that can be learning electronics is much better to manage when shared.

[^exchange]: Especially during a [workshop in collaboration with the kunsthal](https://www.kunsthal.nl/nl/plan-je-bezoek/activiteiten/friday-night-live-operator/), where it was the first time making a circuit for many atendees. It was great to see how people without much electronics experience, figured out circuit making and playing, together.

[^unrepair-night]: The (un)repair cafe is a by-weekly hangout at the Klankschool, where we modify, hack and repair devices. Check the [calendar](https://calendar.klank.school/) for the next event!

[^about-klankschool]: Klankschool is a loose-knit group of sonic practitioners based in Rotterdam who share a common interest in performances, sound art, improvisation and noise. Everyone involved is a teacher, student, musician, janitor and more.

This field guide came together during and with the help of (un)repair nights at the klank.school. <ins>uitbreiden</ins>

![A sound device](/chapters/transistorOSC_white.webp){.img--fullpage}

The guide is split up into five chapters, each focusing on a different stage of salvaging for sound devices.

#### 1. Gathering hardware
*We trace where to find discarded electronics, what to look for, and how industry practices like planned and stylistic obsolescence shape what ends up in the trash.*

#### 2. Dismantling devices
*Opening up devices to uncover design strategies that prevent access: proprietary screws, glued casings, encryption, and the disappearance of service manuals.*

#### 3. Components to salvage
*A practical guide to identifying and extracting useful components—motors, sensors, chips—and understanding how their design reflects built-in lifespans and disposability.*

#### 4. Recipes for making
*Methods for prototyping, modifying, and reusing salvaged parts*

#### 5. Taking inventory
*A moment of reflection on what worked, what didn’t, and what patterns emerge when working with discarded electronics at scale.*

Happy scavenging!
